package com.qmth.teachcloud.task.job;

import com.qmth.boot.core.concurrent.service.ConcurrentService;
import com.qmth.teachcloud.mark.enums.LockType;
import com.qmth.teachcloud.task.job.service.JobService;
import org.quartz.DisallowConcurrentExecution;
import org.quartz.JobExecutionContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.quartz.QuartzJobBean;

import javax.annotation.Resource;

/**
 * AI评卷OCR识别定时任务
 */
//@DisallowConcurrentExecution//串行执行
public class MarkAiJob extends QuartzJobBean {
    private final static Logger log = LoggerFactory.getLogger(MarkAiJob.class);

    @Resource
    JobService jobService;

    @Autowired
    private ConcurrentService concurrentService;

    @Override
    protected void executeInternal(JobExecutionContext jobExecutionContext) {
        if (concurrentService.getReadWriteLock(LockType.AI_MARK_TASK.name()).writeLock().tryLock()) {
            try {
                jobService.autoAiMark();
            } catch (Exception e) {
                log.info("mark-ai-task error");
                e.printStackTrace();
            } finally {
                concurrentService.getReadWriteLock(LockType.AI_MARK_TASK.name()).writeLock().unlock();
            }
        } else {
            log.info("mark-ai-task is running");
        }
    }
}
